4 ms·
Well, I got 93 ms on the same Tale Of Two Cities file, 2x slower than dga's version and 18x slower than my last 5.0 ms Nim version (done to properly avoid hangi
by cb321 6y ago
Well, I got 93 ms on the same Tale Of Two Cities file, 2x slower than dga's version and 18x slower than my last 5.0 ms Nim version (done to properly avoid hanging forever if someone does a "mknod foo.txt p") mentioned elsewhere in this thread (
https://news.ycombinator.com/item?id=24822429 https://news.ycombinator.com/item?id=24822429).
Really, though, all the code for all 6 versions (two Nim, one C, two Rust, one C++) as well as the input file is available to all. So, you should/could double check yourself. As dga mentions in his updated blog there is a lot of compiler/CPU sensitivity.
- Measter 6y agoHuh... that's actually faster than I expected. I figured that the normalization processing overhead would be higher than that.